%global momorel 2

%{!?build_openmpi:%global build_openmpi 1}
%{!?build_mpich2:%global build_mpich2 1}
%define pv_maj 3
%define pv_min 8
%define pv_patch 0
%define pv_majmin %{pv_maj}.%{pv_min}

Summary:        Parallel visualization application for scientific data
Name:           paraview
Version:        %{pv_majmin}.%{pv_patch}
Release:        %{momorel}m%{?dist}
License:        BSD
Group:          Applications/Engineering
URL:            http://www.paraview.org/
Source0:        http://www.paraview.org/files/v%{pv_majmin}/ParaView-%{version}.tar.gz
NoSource:       0
Source1:        paraview_22x22.png
Source2:        paraview.xml
#Add needed link libraries
#http://public.kitware.com/Bug/view.php?id=10298
Patch0:         paraview-3.6.2-libs.patch
#Add some needed includes
Patch1:         paraview-3.8.0-include.patch
#Upstream patch to fix install paths
Patch2:         paraview-3.8.0-installpath.patch
#Installs PointSpriteDemo into incorrect location, remove install for now
#Reported upstream: http://public.kitware.com/mantis/view.php?id=9292
Patch5:         paraview-3.8.0-demo.patch
#Reported upstream: http://public.kitware.com/mantis/view.php?id=7023
Patch7:         paraview-3.2.2-hdf5.patch
#Change H5_USE_16_API_DEFAULT to H5_USE_16_API
Patch8:         paraview-3.8.0-hdf5-1.8.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires(post):   desktop-file-utils
Requires(postun): desktop-file-utils
Requires:       %{name}-data = %{version}-%{release}
BuildRequires:  cmake
%if %{build_openmpi}
BuildRequires:  openmpi-devel >= 1.2.6
%endif
%if %{build_mpich2}
BuildRequires:  mpich2-devel >= 1.2.1
%endif
BuildRequires:  qt-devel >= 4.6.3
BuildRequires:  mesa-libOSMesa-devel
BuildRequires:  python-devel >= 2.6.1
BuildRequires:  tk-devel
BuildRequires:  hdf5-devel >= 1.8.2
BuildRequires:  freetype-devel
BuildRequires:  libtiff-devel
BuildRequires:  zlib-devel
BuildRequires:  libjpeg-devel >= 8a
BuildRequires:  expat-devel
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  readline-devel
BuildRequires:  openssl-devel >= 1.0.0
BuildRequires:  gnuplot
BuildRequires:  wget
Obsoletes:      paraview-demos < %{version}-%{release}
Provides:       paraview-demos = %{version}-%{release}
Obsoletes:      paraview-doc < %{version}-%{release}
Provides:       paraview-doc = %{version}-%{release}

%define paraview_cmake_options \\\
        -DCMAKE_CXX_COMPILER:FILEPATH=$CXX \\\
        -DCMAKE_C_COMPILER:FILEPATH=$CC \\\
        -DTCL_LIBRARY:PATH=tcl \\\
        -DTK_LIBRARY:PATH=tk \\\
        -DPARAVIEW_BUILD_StreamingParaView:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_Streaming:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_Array:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_CosmoFilters:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_Infovis:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_netCDFReaders:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_pvblot:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_SLACTools:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_VisItReaderPlugin:BOOL=OFF \\\
        -DPARAVIEW_ENABLE_PYTHON:BOOL=ON \\\
        -DPARAVIEW_USE_SYSTEM_HDF5:BOOL=ON \\\
        -DVTK_OPENGL_HAS_OSMESA:BOOL=ON \\\
        -DVTK_USE_BOOST:BOOL=ON \\\
        -DVTK_USE_INFOVIS:BOOL=OFF \\\
        -DVTK_USE_N_WAY_ARRAYS:BOOL=ON \\\
        -DVTK_USE_RPATH:BOOL=OFF \\\
        -DVTK_USE_SYSTEM_EXPAT:BOOL=ON \\\
        -DVTK_USE_SYSTEM_FREETYPE:BOOL=ON \\\
        -DVTK_USE_SYSTEM_JPEG:BOOL=ON \\\
        -DVTK_USE_SYSTEM_PNG:BOOL=ON \\\
        -DVTK_USE_SYSTEM_TIFF:BOOL=ON \\\
        -DVTK_USE_SYSTEM_ZLIB:BOOL=ON \\\
        -DBUILD_DOCUMENTATION:BOOL=ON \\\
        -DBUILD_EXAMPLES:BOOL=ON

%description
ParaView is an application designed with the need to visualize large data
sets in mind. The goals of the ParaView project include the following:

    * Develop an open-source, multi-platform visualization application.
    * Support distributed computation models to process large data sets.
    * Create an open, flexible, and intuitive user interface.
    * Develop an extensible architecture based on open standards.

ParaView runs on distributed and shared memory parallel as well as single
processor systems and has been successfully tested on Windows, Linux and
various Unix workstations and clusters. Under the hood, ParaView uses the
Visualization Toolkit as the data processing and rendering engine and has a
user interface written using a unique blend of Tcl/Tk and C++.

NOTE: This version has NOT been compiled with MPI support.


%if %{build_openmpi}
%package        openmpi
Summary:        Parallel visualization application
Group:          Applications/Engineering
Requires:       %{name}-data = %{version}-%{release}
Requires:       openmpi
Requires(post):   desktop-file-utils
Requires(postun): desktop-file-utils
Obsoletes:      %{name}-mpi < %{version}-%{release}
Provides:       %{name}-mpi = %{version}-%{release}

%description    openmpi
This package contains copies of the ParaView server binaries compiled with
OpenMPI.  These are named pvserver-mpi, pvbatch-mpi, etc.
%endif

%if %{build_mpich2}
%package        mpich2
Summary:        Parallel visualization application
Group:          Applications/Engineering
Requires:       %{name}-data = %{version}-%{release}
Requires:       mpich2

%description    mpich2
This package contains copies of the ParaView server binaries compiled with
mpich2.  These are named pvserver_mpich2, pvbatch_mpich2, etc.

You will need to load the mpich2-%{arch} module to setup your path properly.
%endif

%package        data
Summary:        Data files for ParaView
Group:          Applications/Engineering
Requires:       %{name} = %{version}-%{release}
Requires(post):   desktop-file-utils
Requires(postun): desktop-file-utils
BuildArch:      noarch

%description    data
%{summary}.

%package        devel
Summary:        Development files for ParaView
Group:          Applications/Engineering
Requires:       %{name} = %{version}-%{release}
Obsoletes:      %{name}-mpi-devel < %{version}-%{release}
Provides:       %{name}-mpi-devel = %{version}-%{release}

%description    devel
%{summary}.

%prep
%setup -q -n ParaView-%{version}
%patch0 -p1 -b .libs
%patch1 -p1 -b .include
%patch2 -p1 -b .installpath
%patch5 -p1 -b .demo
%patch7 -p1 -b .hdf5
%patch8 -p1 -b .hdf5-1.8
#Remove included hdf5 just to be sure
rm -r Utilities/hdf5

%build
mkdir momonga
pushd momonga
export CC='gcc'
export CXX='g++'
export MAKE='make'
export CFLAGS="$RPM_OPT_FLAGS -DH5_USE_16_API"
export CXXFLAGS="$RPM_OPT_FLAGS -DH5_USE_16_API"
%cmake .. \
        -DPV_INSTALL_LIB_DIR:PATH=%{_lib}/paraview \
        %{paraview_cmake_options}
##Need to run cmake twice to get MPI headers into VTK/Parallel build config
cmake ..
make VERBOSE=1 %{?_smp_mflags}
popd
%if %{build_openmpi}
mkdir momonga-openmpi
pushd momonga-openmpi
%{_openmpi_load}
export CC='gcc'
export CXX='g++'
export MAKE='make'
export CFLAGS="$RPM_OPT_FLAGS -DH5_USE_16_API"
export CXXFLAGS="$RPM_OPT_FLAGS -DH5_USE_16_API"
%cmake .. \
        -DPV_INSTALL_BIN_DIR:PATH=%{_lib}/openmpi/bin \
        -DPV_INSTALL_LIB_DIR:PATH=%{_lib}/openmpi/lib/paraview \
        -DPARAVIEW_USE_MPI:BOOL=ON \
        -DICET_BUILD_TESTING:BOOL=ON \
        -DMPI_COMPILER:FILEPATH=%{_libdir}/openmpi/bin/mpicxx \
        %{paraview_cmake_options}
#Need to run cmake twice to get MPI headers into VTK/Parallel build config
cmake ..
make VERBOSE=1 %{?_smp_mflags}
%{_openmpi_unload}
popd
%endif
%if %{build_mpich2}
mkdir momonga-mpich2
pushd momonga-mpich2
%{_mpich2_load}
export CC='gcc'
export CXX='g++'
export MAKE='make'
export CFLAGS="$RPM_OPT_FLAGS -DH5_USE_16_API"
export CXXFLAGS="$RPM_OPT_FLAGS -DH5_USE_16_API"
%cmake .. \
        -DPV_INSTALL_BIN_DIR:PATH=%{_lib}/mpich2/bin \
        -DPV_INSTALL_LIB_DIR:PATH=%{_lib}/mpich2/lib/paraview \
        -DPARAVIEW_USE_MPI:BOOL=ON \
        -DICET_BUILD_TESTING:BOOL=ON \
        -DMPI_COMPILER:FILEPATH=%{_libdir}/mpich2/bin/mpicxx \
        %{paraview_cmake_options}
#Need to run cmake twice to get MPI headers into VTK/Parallel build config
cmake ..
make VERBOSE=1 %{?_smp_mflags}
%{_mpich2_unload}
popd
%endif

%install
rm -rf %{buildroot}

#Fix permissions
find . \( -name \*.txt -o -name \*.xml -o -name '*.[ch]' -o -name '*.[ch][px][px]' \) -print0 | xargs -0 chmod -x

# Create some needed directories
install -d %{buildroot}%{_datadir}/applications
install -d %{buildroot}%{_datadir}/pixmaps
install -m644 %SOURCE1 %{buildroot}%{_datadir}/pixmaps
install -d %{buildroot}%{_datadir}/mime/packages
install -m644 %SOURCE2 %{buildroot}%{_datadir}/mime/packages

%if %{build_openmpi}
# Install openmpi version
pushd momonga-openmpi
make install DESTDIR=%{buildroot}

#Cleanup %{_bindir}
pushd %{buildroot}%{_libdir}/openmpi/bin
#Don't need mpi versions of these
rm paraview streaming_paraview lproj pvblot pvpython
#Move the remaining mpi binaries out of the way
for f in pvbatch pvdataserver pvrenderserver pvserver smTestDriver
do
   mv $f ${f}_openmpi
done
popd

#Remove mpi copy of includes, man pages, and documentation
rm -rf %{buildroot}%{_includedir}/paraview-%{pv_majmin}
rm -rf %{buildroot}%{_mandir}
popd
%endif

%if %{build_mpich2}
# Install mpich2 version
pushd momonga-mpich2
make install DESTDIR=%{buildroot}

#Cleanup %{_bindir}
pushd %{buildroot}%{_libdir}/mpich2/bin
#Don't need mpi versions of these
rm paraview streaming_paraview lproj pvblot pvpython
#Move the remaining mpi binaries out of the way
for f in pvbatch pvdataserver pvrenderserver pvserver smTestDriver
do
   mv $f ${f}_mpich2
done
popd

#Remove mpi copy of includes, man pages, and documentation
rm -rf %{buildroot}%{_includedir}/paraview-%{pv_majmin}
rm -rf %{buildroot}%{_mandir}
popd
%endif

#Install the normal version
pushd momonga
make install DESTDIR=%{buildroot}

#Create desktop file
cat > paraview.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=ParaView Viewer
GenericName=Data Viewer
Comment=ParaView allows viewing of large data sets
Type=Application
Terminal=false
Icon=paraview_22x22
MimeType=application/x-paraview;
Categories=Application;Graphics;
Exec=paraview
EOF

desktop-file-install --vendor= \
       --add-category Science \
       --add-category Engineering \
       --dir %{buildroot}%{_datadir}/applications/ \
       paraview.desktop

popd

#Don't ship the VTK Qt Designer plugin
rm -r %{buildroot}/usr/plugins

#Don't ship lproj - provided by vtk
rm %{buildroot}%{_bindir}/lproj

%clean
rm -rf %{buildroot}

%post
/sbin/ldconfig
update-desktop-database &> /dev/null ||:

%postun
/sbin/ldconfig
update-desktop-database &> /dev/null ||:

%post   data
update-mime-database %{_datadir}/mime &> /dev/null || :

%postun data
update-mime-database %{_datadir}/mime &> /dev/null || :

%files
%defattr(-,root,root,-)
%doc License_v1.2.txt
%{_bindir}/paraview
%{_bindir}/pvbatch
%{_bindir}/pvblot
%{_bindir}/pvdataserver
%{_bindir}/pvpython
%{_bindir}/pvrenderserver
%{_bindir}/pvserver
%{_bindir}/smTestDriver
%{_bindir}/streaming_paraview
%{_libdir}/paraview/
%exclude %{_libdir}/paraview/doc/
%{python_sitelib}/Xdmf/

%if %{build_mpich2}
%files openmpi
%defattr(-,root,root,-)
%doc License_v1.2.txt
%{_libdir}/openmpi/bin/pvbatch_openmpi
%{_libdir}/openmpi/bin/pvdataserver_openmpi
%{_libdir}/openmpi/bin/pvrenderserver_openmpi
%{_libdir}/openmpi/bin/pvserver_openmpi
%{_libdir}/openmpi/bin/smTestDriver_openmpi
%{_libdir}/openmpi/lib/paraview
%endif

%if %{build_mpich2}
%files mpich2
%defattr(-,root,root,-)
%doc License_v1.2.txt
%{_libdir}/mpich2/bin/pvbatch_mpich2
%{_libdir}/mpich2/bin/pvdataserver_mpich2
%{_libdir}/mpich2/bin/pvrenderserver_mpich2
%{_libdir}/mpich2/bin/pvserver_mpich2
%{_libdir}/mpich2/bin/smTestDriver_mpich2
%{_libdir}/mpich2/lib/paraview
%endif

%files data
%defattr(-,root,root,-)
%{_datadir}/applications/paraview.desktop
%{_datadir}/pixmaps/paraview_22x22.png
%{_datadir}/mime/packages/paraview.xml

%files devel
%defattr(-,root,root,-)
%{_includedir}/paraview-%{pv_majmin}/
%doc %{_libdir}/paraview/doc/

%changelog
* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (3.8.0-2m)
- full rebuild for mo7 release

* Sat Aug  7 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (3.8.0-1m)
- update to 3.8.0
- rename from mpi to openmpi subpackage
- add mpich2 subpackage
- remove doc subpackage
- set BuildArch: noarch to data subpackage
- sync with Fedora devel (3.8.0-3)

* Wed Jun 30 2010 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.4.0-12m)
- remove Requires: qt-assistant-adp

* Mon Jun 28 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (3.4.0-11m)
- rebuild against qt-4.6.3-1m

* Sat May  8 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (3.4.0-10m)
- rebuild against qt-4.7.0 and qt-assistant-adp-4.6.2

* Tue May 04 2010 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.4.0-9m)
- rebuild against readline6

* Mon May  3 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.4.0-8m)
- explicitly link libm

* Sat Apr 10 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.4.0-7m)
- rebuild against libjpeg-8a

* Sun Apr  4 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.4.0-6m)
- rebuild against openssl-1.0.0

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.4.0-5m)
- rebuild against gcc-4.4 and glibc-2.11

* Fri Sep 11 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (3.4.0-4m)
- rebuild against libjpeg-7

* Tue Apr 07 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.4.0-3m)
- rebuild against openssl-0.9.8k

* Wed Apr  1 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.4.0-2m)
- remove %%{_libdir}/paraview{,-mpi}/assistant-real
- Requires(*): shared-mime-info

* Tue Mar 31 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.4.0-1m)
- sync with Rawhide (3.4.0-4)

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.2.2-4m)
- rebuild against rpm-4.6

* Fri Jan  2 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.2.2-3m)
- rebuild against python-2.6.1

* Sat Nov 22 2008 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.2.2-2m)
- rebuild against hdf5-1.8.2

* Thu Jul 10 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.2.2-1m)
- version 3.2.2, cmake26 build fix
- import cmake2.6.patch from debian
 +- paraview (3.2.2-1) unstable; urgency=low
 +- [ Ondrej Certik ]
 +- cmake2.6.patch added to configure well with cmake2.6
- update qt.patch

* Sun May 11 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (3.2.1-3m)
- rebuild against qt-4.4.0-1m

* Thu May  8 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (3.2.1-2m)
- rebuild against openmpi-1.2.6

* Thu May 08 2008 Masayuki SANO <nosanosa@momonga-linux.org>
- (3.2.1-1m)
- import to Momonga (from Fedora)

* Wed Mar 5 2008 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-5
- Rebuild for hdf5 1.8.0 using compatability API define and new patch

* Mon Feb 18 2008 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-4
- Add patch to compile with gcc 4.3

* Fri Jan 18 2008 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-3
- Add patch to fix parallel make
- Obsolete demos package (bug #428528)

* Tue Dec 18 2007 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-2
- Name ld.so.conf.d file with .conf extension
- Drop parallel make for now

* Mon Dec 03 2007 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-1
- Update to 3.2.1
- Use macros for version numbers
- Add patches to fix documentation install location and use assistant-qt4,
  not install copies of Qt libraries, and not use rpath.
- Install ld.so.conf.d file
- Fixup desktop files

* Thu Aug 23 2007 - Orion Poplawski <orion@cora.nwra.com> - 3.0.2-2
- Update license tag to BSD
- Fix make %%{_smp_mflags}
- Rebuild for ppc32

* Wed Jul 11 2007 - Orion Poplawski <orion@cora.nwra.com> - 3.0.2-1
- Update to 3.0.2
- Turn mpi build back on
- Add devel packages
- Remove demo package no longer in upstream
- Use cmake macros

* Thu Mar 08 2007 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-6
- Don't build mpi version until upstream fixes the build system

* Fri Dec 22 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-5
- Fix .so permissions
- Patch for const issue
- Patch for new cmake
- Build with openmpi

* Thu Dec 14 2006 - Jef Spaleta <jspaleta@gmail.com> - 2.4.4-4
- Bump and build for python 2.5

* Fri Oct  6 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-3
- Install needed python libraries to get around make install bug

* Wed Oct  4 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-2
- Re-enable OSMESA support for FC6
- Enable python wrapping

* Fri Sep 15 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-1
- Update to 2.4.4

* Thu Jun 29 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-8
- No OSMesa support in FC5
- Make data sub-package pull in main package (bug #193837)
- A patch from CVS to fix vtkXOpenRenderWindow.cxx
- Need lam-devel for FC6

* Fri Apr 21 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-7
- Re-enable ppc

* Mon Apr 17 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-6
- Exclude ppc due to gcc bug #189160

* Wed Apr 12 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-5
- Cleanup permissions

* Mon Apr 10 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-4
- Add icon and cleanup desktop file

* Mon Apr 10 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-3
- Add VTK_USE_MANGLE_MESA for off screen rendering
- Cleanup source permisions
- Add an initial .desktop file
- Make requirement on -data specific to version
- Don't package Ice-T man pages and cmake files

* Thu Apr  6 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-2
- Add mpi version

* Tue Apr  4 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-1
- Initial Fedora Extras version
